Mapping Columns and Expressions — SQLAlchemy 1.0 Documentation

Release: 1.0.13 | Release Date: May 16, 2016

# SQLAlchemy 1.0 Documentation

# Mapping Columns and Expressions

The following sections discuss how table columns and SQL expressions are mapped to individual object attributes.

- Mapping Table Columns
  - Naming Columns Distinctly from Attribute Names
  - Automating Column Naming Schemes from Reflected Tables
  - Naming All Columns with a Prefix
  - Using column_property for column level options
  - Mapping a Subset of Table Columns
- SQL Expressions as Mapped Attributes
  - Using a Hybrid
  - Using column_property
  - Using a plain descriptor
- Changing Attribute Behavior
  - Simple Validators
  - Using Descriptors and Hybrids
  - Synonyms
  - Operator Customization
- Composite Column Types
  - Tracking In-Place Mutations on Composites
  - Redefining Comparison Operations for Composites